@@ -89,6 +89,11 @@ public class SpecialUseDefaultFolderChecker extends IMAPDefaultFolderChecker {
         this.hasCreateSpecialUse = hasCreateSpecialUse;
     }
 
+    @Override
+    protected boolean setSpecialUseForExisting() {
+        return hasCreateSpecialUse;
+    }
+
     @Override
     protected void createIfNonExisting(IMAPFolder f, int type, char sep, String namespace, int index) throws MessagingException {
         if (!f.exists()) {
@@ -105,7 +110,7 @@ public class SpecialUseDefaultFolderChecker extends IMAPDefaultFolderChecker {
                         try {
                             IMAPCommandsCollection.setSpecialUses(f, Collections.singletonList(flag));
                         } catch (Exception e) {
-                            LOG.info("Failed to set {} flag for new standard {} folder (full-name=\"{}\", namespace=\"{}\") for login {} (account={}) on IMAP server {} (user={}, context={})", flag, getFallbackName(index), f.getFullName(), namespace, imapConfig.getLogin(), Integer.valueOf(accountId), imapConfig.getServer(), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()));
+                            LOG.debug("Failed to set {} flag for new standard {} folder (full-name=\"{}\", namespace=\"{}\") for login {} (account={}) on IMAP server {} (user={}, context={})", flag, getFallbackName(index), f.getFullName(), namespace, imapConfig.getLogin(), Integer.valueOf(accountId), imapConfig.getServer(), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()), e);
                         }
                     }
                 }
@@ -121,7 +126,7 @@ public class SpecialUseDefaultFolderChecker extends IMAPDefaultFolderChecker {
                 try {
                     IMAPCommandsCollection.setSpecialUses(f, Collections.singletonList(flag));
                 } catch (Exception e) {
-                    LOG.info("Failed to set {} flag for existing standard {} folder (full-name=\"{}\", namespace=\"{}\") for login {} (account={}) on IMAP server {} (user={}, context={})", flag, getFallbackName(index), f.getFullName(), namespace, imapConfig.getLogin(), Integer.valueOf(accountId), imapConfig.getServer(), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()));
+                    LOG.debug("Failed to set {} flag for existing standard {} folder (full-name=\"{}\", namespace=\"{}\") for login {} (account={}) on IMAP server {} (user={}, context={})", flag, getFallbackName(index), f.getFullName(), namespace, imapConfig.getLogin(), Integer.valueOf(accountId), imapConfig.getServer(), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()), e);
                 }
             }
         }
