@@ -115,6 +115,8 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
 
     private int imapConnectionTimeout;
 
+    private int fetchTimeout;
+
     private int imapTemporaryDown;
 
     private String imapAuthEnc;
@@ -273,6 +275,18 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
             }
         }
 
+        /*{
+            final String fetchTimeoutMillisStr = configuration.getProperty("com.openexchange.imap.fetchTimeoutMillis", "10000").trim();
+            try {
+                fetchTimeout = Integer.parseInt(fetchTimeoutMillisStr);
+                logBuilder.append("\tIMAP FETCH Timeout: ").append(fetchTimeout).append('\n');
+            } catch (final NumberFormatException e) {
+                fetchTimeout = 10000;
+                logBuilder.append("\tIMAP FETCH Timeout: Invalid value \"").append(fetchTimeoutMillisStr).append(
+                    "\". Setting to fallback: ").append(fetchTimeout).append('\n');
+            }
+        }*/
+
         {
             final String imapTempDownStr = configuration.getProperty("com.openexchange.imap.imapTemporaryDown", "0").trim();
             try {
@@ -425,6 +439,7 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         supportsACLs = null;
         imapTimeout = 0;
         imapConnectionTimeout = 0;
+        fetchTimeout = 10000;
         imapTemporaryDown = 0;
         imapAuthEnc = null;
         entity2AclImpl = null;
@@ -484,6 +499,17 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         return imapConnectionTimeout;
     }
 
+    /**
+     * Gets the special timeout for FETCH commands.
+     * <p>
+     * Default is 10.000 milliseconds
+     *
+     * @return The special timeout for FETCH commands
+     */
+    public int getFetchTimeout() {
+        return fetchTimeout;
+    }
+
     @Override
     public int getImapTemporaryDown() {
         return imapTemporaryDown;
@@ -587,6 +613,16 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         return mailProperties.isAllowNestedDefaultFolderOnAltNamespace();
     }
 
+    @Override
+    public boolean isEnforceSecureConnection() {
+        return mailProperties.isEnforceSecureConnection();
+    }
+
+    @Override
+    public void setEnforceSecureConnection(boolean enforceSecureConnection) {
+        mailProperties.setEnforceSecureConnection(enforceSecureConnection);
+    }
+
     @Override
     public boolean isIgnoreSubscription() {
         return mailProperties.isIgnoreSubscription();
