@@ -106,6 +106,7 @@ public final class IMAPFolderConverter {
         private final int sessionUser;
         private final String fullname;
         private final char separator;
+        private final String otherUserNamespace;
 
         /**
          * Initializes a new {@link Entity2ACLArgsImpl}.
@@ -115,19 +116,21 @@ public final class IMAPFolderConverter {
          * @param sessionUser The session user ID
          * @param fullname The IMAP folder's full name
          * @param separator The separator character
+         * @param otherUserNamespaces The namespace for other users
          */
-        public Entity2ACLArgsImpl(final int accountId, final String serverUrl, final int sessionUser, final String fullname, final char separator) {
+        Entity2ACLArgsImpl(int accountId, String serverUrl, int sessionUser, String fullname, char separator, String[] otherUserNamespaces) {
             super();
             this.accountId = accountId;
             this.serverUrl = serverUrl;
             this.sessionUser = sessionUser;
             this.fullname = fullname;
             this.separator = separator;
+            this.otherUserNamespace = null == otherUserNamespaces || otherUserNamespaces.length == 0 ? null : otherUserNamespaces[0];
         }
 
         @Override
         public Object[] getArguments(final IMAPServer imapServer) throws OXException {
-            return imapServer.getArguments(accountId, serverUrl, sessionUser, fullname, separator);
+            return imapServer.getArguments(accountId, serverUrl, sessionUser, fullname, separator, otherUserNamespace);
         }
     }
 
@@ -167,14 +170,15 @@ public final class IMAPFolderConverter {
      * @return An appropriate implementation of {@link Entity2ACLArgs}
      * @throws OXException If IMAP folder's attributes cannot be accessed
      */
-    public static Entity2ACLArgs getEntity2AclArgs(final Session session, final IMAPFolder imapFolder, final IMAPConfig imapConfig) throws OXException {
+    public static Entity2ACLArgs getEntity2AclArgs(Session session, IMAPFolder imapFolder, IMAPConfig imapConfig) throws OXException {
         try {
             return new Entity2ACLArgsImpl(
                 imapConfig.getAccountId(),
                 new StringBuilder(36).append(IDNA.toASCII(imapConfig.getServer())).append(':').append(imapConfig.getPort()).toString(),
                 session.getUserId(),
                 imapFolder.getFullName(),
-                ListLsubCache.getSeparator(imapConfig.getAccountId(), imapFolder, session));
+                ListLsubCache.getSeparator(imapConfig.getAccountId(), imapFolder, session, imapConfig.getIMAPProperties().isIgnoreSubscription()),
+                NamespaceFoldersCache.getUserNamespaces((IMAPStore) imapFolder.getStore(), true, session, imapConfig.getAccountId()));
         } catch (final MessagingException e) {
             throw MimeMailException.handleMessagingException(e, imapConfig, session);
         }
@@ -248,7 +252,7 @@ public final class IMAPFolderConverter {
                 mailFolder.setRootFolder(false);
                 // Get appropriate entries
                 final int accountId = imapConfig.getAccountId();
-                final ListLsubEntry listEntry = ListLsubCache.getCachedLISTEntry(imapFullName, accountId, imapFolder, session);
+                final ListLsubEntry listEntry = ListLsubCache.getCachedLISTEntry(imapFullName, accountId, imapFolder, session, imapConfig.getIMAPProperties().isIgnoreSubscription());
                 /*
                  * Check existence
                  */
@@ -265,7 +269,7 @@ public final class IMAPFolderConverter {
                     String owner = null;
                     for (int i = 0; !shared && i < users.length; i++) {
                         final String userNamespace = users[i];
-                        if (!isEmpty(userNamespace)) {
+                        if (!com.openexchange.java.Strings.isEmpty(userNamespace)) {
                             if (imapFullName.equals(userNamespace)) {
                                 shared = true;
                             } else {
@@ -295,7 +299,7 @@ public final class IMAPFolderConverter {
                         final String[] personals = NamespaceFoldersCache.getPersonalNamespaces(imapStore, true, session, accountId);
                         for (int i = 0; !shared && i < shares.length; i++) {
                             final String sharedNamespace = shares[i];
-                            if (!isEmpty(sharedNamespace)) {
+                            if (!com.openexchange.java.Strings.isEmpty(sharedNamespace)) {
                                 if (imapFullName.equals(sharedNamespace)) {
                                     isPublic = true;
                                 } else {
@@ -372,7 +376,7 @@ public final class IMAPFolderConverter {
                      * Check reliably for subscribed subfolders through LSUB command since folder attributes need not to to be present as
                      * per RFC 3501
                      */
-                    mailFolder.setSubscribedSubfolders(ListLsubCache.hasAnySubscribedSubfolder(imapFullName, accountId, imapFolder, session));
+                    mailFolder.setSubscribedSubfolders(ListLsubCache.hasAnySubscribedSubfolder(imapFullName, accountId, imapFolder, session, imapConfig.getIMAPProperties().isIgnoreSubscription()));
                 }
                 /*
                  * Set full name, name, and parent full name
@@ -558,7 +562,7 @@ public final class IMAPFolderConverter {
              * This is the tricky case: Allow subfolder creation for a common imap folder but deny it for imap server's
              * namespace folders
              */
-            if (checkForNamespaceFolder(imapFullName, imapAccess.getIMAPStore(), session, accountId)) {
+            if (checkForNamespaceFolder(imapFullName, imapAccess.getIMAPStore(), session, accountId, imapConfig.getIMAPProperties().isIgnoreSubscription())) {
                 ownPermission.parseRights((ownRights = (Rights) RIGHTS_EMPTY.clone()), imapConfig);
             } else {
                 ownPermission.setAllPermission(
@@ -601,9 +605,10 @@ public final class IMAPFolderConverter {
             mailFolder.setExists(true);
             mailFolder.setShared(false);
             mailFolder.setPublic(true);
-            mailFolder.setSeparator(ListLsubCache.getSeparator(imapConfig.getAccountId(), rootFolder, session));
+            boolean ignoreSubscription = imapConfig.getIMAPProperties().isIgnoreSubscription();
+            mailFolder.setSeparator(ListLsubCache.getSeparator(imapConfig.getAccountId(), rootFolder, session, ignoreSubscription));
             final String imapFullname = "";
-            final ListLsubEntry listEntry = ListLsubCache.getCachedLISTEntry(imapFullname, imapConfig.getAccountId(), rootFolder, session);
+            final ListLsubEntry listEntry = ListLsubCache.getCachedLISTEntry(imapFullname, imapConfig.getAccountId(), rootFolder, session, ignoreSubscription);
             final Set<String> attrs = listEntry.getAttributes();
             if (null != attrs && !attrs.isEmpty()) {
                 if (attrs.contains(ATTRIBUTE_NON_EXISTENT)) {
@@ -684,8 +689,9 @@ public final class IMAPFolderConverter {
      * @param ownRights The rights granted to IMAP folder for session user
      * @param ctx The context
      * @throws OXException If ACLs cannot be mapped
+     * @throws MessagingException If a messaging error occurs
      */
-    private static void applyACL2Permissions(final IMAPFolder imapFolder, final ListLsubEntry listEntry, final Session session, final IMAPConfig imapConfig, final MailFolder mailFolder, final Rights ownRights, final Context ctx) throws OXException {
+    private static void applyACL2Permissions(final IMAPFolder imapFolder, final ListLsubEntry listEntry, final Session session, final IMAPConfig imapConfig, final MailFolder mailFolder, final Rights ownRights, final Context ctx) throws OXException, MessagingException {
         final ACL[] acls;
         try {
             final List<ACL> list = listEntry.getACLs();
@@ -703,7 +709,7 @@ public final class IMAPFolderConverter {
             }
             throw MimeMailException.handleMessagingException(e);
         }
-        final Entity2ACLArgs args = new Entity2ACLArgsImpl(imapConfig.getAccountId(), new StringBuilder(36).append(IDNA.toASCII(imapConfig.getServer())).append(':').append(imapConfig.getPort()).toString(), session.getUserId(), imapFolder.getFullName(), listEntry.getSeparator());
+        Entity2ACLArgs args = new Entity2ACLArgsImpl(imapConfig.getAccountId(), new StringBuilder(36).append(IDNA.toASCII(imapConfig.getServer())).append(':').append(imapConfig.getPort()).toString(), session.getUserId(), imapFolder.getFullName(), listEntry.getSeparator(), NamespaceFoldersCache.getUserNamespaces((IMAPStore) imapFolder.getStore(), true, session, imapConfig.getAccountId()));
         boolean userPermAdded = false;
         for (int j = 0; j < acls.length; j++) {
             final ACLPermission aclPerm = new ACLPermission();
@@ -775,7 +781,7 @@ public final class IMAPFolderConverter {
         return (e.isPrefix("ACL") && (Entity2ACLExceptionCode.RESOLVE_USER_FAILED.getNumber() == code)) || (e.isPrefix("USR") && (LdapExceptionCode.USER_NOT_FOUND.getNumber() == code));
     }
 
-    private static boolean checkForNamespaceFolder(final String fullName, final IMAPStore imapStore, final Session session, final int accountId) throws MessagingException, OXException {
+    private static boolean checkForNamespaceFolder(final String fullName, final IMAPStore imapStore, final Session session, final int accountId, boolean ignoreLsub) throws MessagingException, OXException {
         /*
          * Check for namespace folder
          */
@@ -795,7 +801,7 @@ public final class IMAPFolderConverter {
                     if (userFolders[i].startsWith(fullName)) {
                         return true;
                     }
-                    final List<ListLsubEntry> children = ListLsubCache.getCachedLISTEntry(userFolders[i], accountId, imapStore, session).getChildren();
+                    final List<ListLsubEntry> children = ListLsubCache.getCachedLISTEntry(userFolders[i], accountId, imapStore, session, ignoreLsub).getChildren();
                     for (final ListLsubEntry entry : children) {
                         if (entry.getFullName().startsWith(fullName)) {
                             return true;
@@ -889,17 +895,4 @@ public final class IMAPFolderConverter {
             LOG.debug("Failed MYRIGHTS for: {}", fullName, e);
         }
     }
-
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
-    }
-
 }
