@@ -51,6 +51,7 @@ package com.openexchange.imap.threader.references;
 
 import static com.openexchange.imap.command.MailMessageFetchIMAPCommand.getFetchCommand;
 import static com.openexchange.imap.command.MailMessageFetchIMAPCommand.handleFetchRespone;
+import static com.openexchange.imap.util.ImapUtility.prepareImapCommandForLogging;
 import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -62,10 +63,12 @@ import javax.mail.MessagingException;
 import javax.mail.UIDFolder;
 import com.openexchange.exception.OXException;
 import com.openexchange.imap.IMAPException;
+import com.openexchange.imap.IMAPServerInfo;
 import com.openexchange.imap.command.MailMessageFetchIMAPCommand;
 import com.openexchange.imap.threadsort.MessageInfo;
 import com.openexchange.imap.threadsort.ThreadSortNode;
 import com.openexchange.imap.util.ImapUtility;
+import com.openexchange.log.LogProperties;
 import com.openexchange.mail.MailField;
 import com.openexchange.mail.OrderDirection;
 import com.openexchange.mail.dataobjects.IDMailMessage;
@@ -79,7 +82,6 @@ import com.sun.mail.iap.Response;
 import com.sun.mail.imap.IMAPFolder;
 import com.sun.mail.imap.protocol.FetchResponse;
 import com.sun.mail.imap.protocol.IMAPProtocol;
-import com.sun.mail.imap.protocol.IMAPResponse;
 
 
 /**
@@ -105,7 +107,7 @@ public final class Conversations {
         fp.add(UIDFolder.FetchProfileItem.UID);
         fp.add("References");
         fp.add("Message-Id");
-        fp.add("In-Reply-To");
+        //fp.add("In-Reply-To");
         FETCH_PROFILE_CONVERSATION_BY_HEADERS = fp;
         fp = new FetchProfile();
         fp.add("References");
@@ -135,6 +137,29 @@ public final class Conversations {
         return fp;
     }
 
+    /**
+     * Gets the <i>"by headers"</i> fetch profile including specified fields.
+     *
+     * @param fields The fields to add
+     * @return The <i>"by headers"</i> fetch profile
+     */
+    public static FetchProfile getFetchProfileConversationByHeaders(MailField... fields) {
+        FetchProfile fp = new FetchProfile();
+        fp.add(UIDFolder.FetchProfileItem.UID);
+        fp.add("References");
+        fp.add("Message-Id");
+        if (null != fields) {
+            for (MailField field : fields) {
+                if (MailField.RECEIVED_DATE.equals(field)) {
+                    fp.add(MailMessageFetchIMAPCommand.INTERNALDATE);
+                } else {
+                    MimeStorageUtility.addFetchItem(fp, field);
+                }
+            }
+        }
+        return fp;
+    }
+
     /**
      * Checks specified {@link FetchProfile} to contain needed items/headers for building up conversations.
      *
@@ -189,6 +214,8 @@ public final class Conversations {
             }
         } else {
             // Add 'In-Reply-To' to FetchProfile if absent
+            /*-
+             *
             {
                 boolean found = false;
                 final Item envelope = FetchProfile.Item.ENVELOPE;
@@ -213,6 +240,7 @@ public final class Conversations {
                     }
                 }
             }
+             */
             // Add 'Message-Id' to FetchProfile if absent
             {
                 boolean found = false;
@@ -242,20 +270,6 @@ public final class Conversations {
         return fetchProfile;
     }
 
-    /**
-     * Retrieves <b><small>UNFOLDED</small></b> conversations for specified IMAP folder.
-     *
-     * @param imapFolder The IMAP folder
-     * @param lookAhead The limit
-     * @param order The order direction that controls which chunk (oldest vs. most recent) to select
-     * @param byEnvelope Whether to build-up using ENVELOPE; otherwise <code>false</code>
-     * @return The unfolded conversations
-     * @throws MessagingException If a messaging error occurs
-     */
-    public static List<Conversation> conversationsFor(final IMAPFolder imapFolder, final int lookAhead, final OrderDirection order, final boolean byEnvelope) throws MessagingException {
-        return conversationsFor(imapFolder, lookAhead, order, null, byEnvelope);
-    }
-
     /**
      * Retrieves <b><small>UNFOLDED</small></b> conversations for specified IMAP folder.
      *
@@ -263,12 +277,13 @@ public final class Conversations {
      * @param lookAhead The limit
      * @param order The order direction that controls which chunk (oldest vs. most recent) to select
      * @param fetchProfile The fetch profile
+     * @param serverInfo The IMAP server information
      * @param byEnvelope Whether to build-up using ENVELOPE; otherwise <code>false</code>
      * @return The unfolded conversations
      * @throws MessagingException If a messaging error occurs
      */
-    public static List<Conversation> conversationsFor(final IMAPFolder imapFolder, final int lookAhead, final OrderDirection order, final FetchProfile fetchProfile, final boolean byEnvelope) throws MessagingException {
-        final List<MailMessage> messages = messagesFor(imapFolder, lookAhead, order, fetchProfile, byEnvelope);
+    public static List<Conversation> conversationsFor(IMAPFolder imapFolder, int lookAhead, OrderDirection order, FetchProfile fetchProfile, IMAPServerInfo serverInfo, boolean byEnvelope) throws MessagingException {
+        final List<MailMessage> messages = messagesFor(imapFolder, lookAhead, order, fetchProfile, serverInfo, byEnvelope);
         if (null == messages || messages.isEmpty()) {
             return Collections.<Conversation> emptyList();
         }
@@ -286,12 +301,13 @@ public final class Conversations {
      * @param lookAhead The limit
      * @param order The order direction that controls which chunk (oldest vs. most recent) to select
      * @param fetchProfile The fetch profile
+     * @param serverInfo The IMAP server information
      * @param byEnvelope Whether to build-up using ENVELOPE; otherwise <code>false</code>
      * @return The messages with conversation information (References, In-Reply-To, Message-Id)
      * @throws MessagingException If a messaging error occurs
      */
     @SuppressWarnings("unchecked")
-    public static List<MailMessage> messagesFor(final IMAPFolder imapFolder, final int lookAhead, final OrderDirection order, final FetchProfile fetchProfile, final boolean byEnvelope) throws MessagingException {
+    public static List<MailMessage> messagesFor(final IMAPFolder imapFolder, final int lookAhead, final OrderDirection order, final FetchProfile fetchProfile, final IMAPServerInfo serverInfo, final boolean byEnvelope) throws MessagingException {
         final int messageCount = imapFolder.getMessageCount();
         if (messageCount <= 0) {
             /*
@@ -322,7 +338,7 @@ public final class Conversations {
                         }
                     }
                     final FetchProfile fp = null == fetchProfile ? (byEnvelope ? FETCH_PROFILE_CONVERSATION_BY_ENVELOPE : FETCH_PROFILE_CONVERSATION_BY_HEADERS) : checkFetchProfile(fetchProfile, byEnvelope);
-                    sb.append(" (").append(getFetchCommand(protocol.isREV1(), fp, false)).append(')');
+                    sb.append(" (").append(getFetchCommand(protocol.isREV1(), fp, false, serverInfo)).append(')');
                     command = sb.toString();
                     sb = null;
                     // Execute command
@@ -339,11 +355,10 @@ public final class Conversations {
                         final List<MailMessage> mails = new ArrayList<MailMessage>(messageCount);
                         final String fullName = imapFolder.getFullName();
                         final char sep = imapFolder.getSeparator();
-                        final String sFetch = "FETCH";
                         final String sInReplyTo = "In-Reply-To";
                         final String sReferences = "References";
                         for (int j = 0; j < len; j++) {
-                            if (sFetch.equals(((IMAPResponse) r[j]).getKey())) {
+                            if (r[j] instanceof FetchResponse) {
                                 final MailMessage message = handleFetchRespone((FetchResponse) r[j], fullName, sep);
                                 final String references = message.getFirstHeader(sReferences);
                                 if (null == references) {
@@ -368,16 +383,13 @@ public final class Conversations {
                     if (ImapUtility.isInvalidMessageset(response)) {
                         return Collections.<Conversation> emptyList();
                     }
-                    throw new BadCommandException(IMAPException.getFormattedMessage(
-                        IMAPException.Code.PROTOCOL_ERROR,
-                        command,
-                        ImapUtility.appendCommandInfo(response.toString(), imapFolder)));
+                    LogProperties.putProperty(LogProperties.Name.MAIL_COMMAND, prepareImapCommandForLogging(command));
+                    throw new BadCommandException(IMAPException.getFormattedMessage(IMAPException.Code.PROTOCOL_ERROR, command, ImapUtility.appendCommandInfo(response.toString(), imapFolder)));
                 } else if (response.isNO()) {
-                    throw new CommandFailedException(IMAPException.getFormattedMessage(
-                        IMAPException.Code.PROTOCOL_ERROR,
-                        command,
-                        ImapUtility.appendCommandInfo(response.toString(), imapFolder)));
+                    LogProperties.putProperty(LogProperties.Name.MAIL_COMMAND, prepareImapCommandForLogging(command));
+                    throw new CommandFailedException(IMAPException.getFormattedMessage(IMAPException.Code.PROTOCOL_ERROR, command, ImapUtility.appendCommandInfo(response.toString(), imapFolder)));
                 } else {
+                    LogProperties.putProperty(LogProperties.Name.MAIL_COMMAND, prepareImapCommandForLogging(command));
                     protocol.handleResult(response);
                 }
                 return Collections.<MailMessage> emptyList();
